function samples = read_car(fname)
% reads and preprocesses raw input data

% domain: car insurance (havarijni pojisteni), liability insurance (povinne ruceni)
% samples: each sample corresponds to single object (car)

% variables (network nodes):
% Accident -- driver's past accidents -- 3 year period (none caused victim)
% Age -- driver's age (young mid-life old)
% AntiTheft -- the car has an anti-theft device (yes no)
% Area -- driver's permanent address/residence (safe neutral dangerous)
% CarInsurance -- proposed insurance rate/expected costs (malus regular bonus)
% CarValue -- the actual value of the car (low regular high)
% DriversMileage -- driver's lifelong mileage (low common high)
% DrivingSkills -- driver's skills (unskilled common professional)
% Gender -- sex (male female)
% MedicalCheck -- the result of medical examination (passed good excellent)
% LiabilityInsurance -- proposed insurance rate/expected costs (malus regular bonus)

Accident = 1; Age = 2; AntiTheft = 3; Area = 4; CarInsurance = 5; CarValue = 6; DriversMileage=7; DrivingSkills = 8; Gender=9; MedicalCheck = 10; LiabilityInsurance = 11;
 
% the number of variables
N=11;
names = {'Accident','Age','AntiTheft','Area','CarInsurance','CarValue','DriversMileage','DrivingSkills','Gender','MedicalCheck','LiabilityInsurance'};
node_sizes = [3 3 2 3 3 3 3 3 2 3 3];

fid = fopen(fname);
data_raw = textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s','delimiter',',');

nsamples = size(data_raw{1,1},1);

% prevod textove reprezentace na ciselnou
for i = 1 : nsamples
    switch data_raw{1,Accident}{i,1}
        case 'none',             data_raw{1,Accident}{i,1}=1;
        case 'caused',           data_raw{1,Accident}{i,1}=2;
        case 'victim',           data_raw{1,Accident}{i,1}=3;
        case 'NaN',              data_raw{1,Accident}{i,1}=NaN;
    end
    switch data_raw{1,Age}{i,1}
        case 'young',            data_raw{1,Age}{i,1}=1;
        case 'midlife',          data_raw{1,Age}{i,1}=2;
        case 'old',              data_raw{1,Age}{i,1}=3;
        case 'NaN',              data_raw{1,Age}{i,1}=NaN;
    end
    switch data_raw{1,AntiTheft}{i,1}
        case 'yes',              data_raw{1,AntiTheft}{i,1}=1;
        case 'no',               data_raw{1,AntiTheft}{i,1}=2;
        case 'NaN',              data_raw{1,AntiTheft}{i,1}=NaN;
    end
    switch data_raw{1,Area}{i,1}
        case 'safe',             data_raw{1,Area}{i,1}=1;
        case 'neutral',          data_raw{1,Area}{i,1}=2;
        case 'dangerous',        data_raw{1,Area}{i,1}=3;
        case 'NaN',              data_raw{1,Area}{i,1}=NaN;
    end
    switch data_raw{1,CarInsurance}{i,1}
        case 'malus',            data_raw{1,CarInsurance}{i,1}=1;
        case 'regular',          data_raw{1,CarInsurance}{i,1}=2;
        case 'bonus',            data_raw{1,CarInsurance}{i,1}=3;
        case 'NaN',              data_raw{1,CarInsurance}{i,1}=NaN;
    end
    switch data_raw{1,CarValue}{i,1}
        case 'low',              data_raw{1,CarValue}{i,1}=1;
        case 'regular',          data_raw{1,CarValue}{i,1}=2;
        case 'high',             data_raw{1,CarValue}{i,1}=3;
        case 'NaN',              data_raw{1,CarValue}{i,1}=NaN;
    end
    switch data_raw{1,DriversMileage}{i,1}
        case 'low',              data_raw{1,DriversMileage}{i,1}=1;
        case 'common',           data_raw{1,DriversMileage}{i,1}=2;
        case 'high',             data_raw{1,DriversMileage}{i,1}=3;
        case 'NaN',              data_raw{1,DriversMileage}{i,1}=NaN;
    end
    switch data_raw{1,DrivingSkills}{i,1}
        case 'unskilled',        data_raw{1,DrivingSkills}{i,1}=1;
        case 'common',           data_raw{1,DrivingSkills}{i,1}=2;
        case 'professional',     data_raw{1,DrivingSkills}{i,1}=3;
        case 'NaN',              data_raw{1,DrivingSkills}{i,1}=NaN;
    end
    switch data_raw{1,Gender}{i,1}
        case 'male',             data_raw{1,Gender}{i,1}=1;
        case 'female',           data_raw{1,Gender}{i,1}=2;
        case 'NaN',              data_raw{1,Gender}{i,1}=NaN;
    end
    switch data_raw{1,MedicalCheck}{i,1}
        case 'passed',           data_raw{1,MedicalCheck}{i,1}=1;
        case 'good',             data_raw{1,MedicalCheck}{i,1}=2;
        case 'excellent',        data_raw{1,MedicalCheck}{i,1}=3;
        case 'NaN',              data_raw{1,MedicalCheck}{i,1}=NaN;
    end
    switch data_raw{1,LiabilityInsurance}{i,1}
        case 'malus',            data_raw{1,LiabilityInsurance}{i,1}=1;
        case 'regular',          data_raw{1,LiabilityInsurance}{i,1}=2;
        case 'bonus',            data_raw{1,LiabilityInsurance}{i,1}=3;
        case 'NaN',              data_raw{1,LiabilityInsurance}{i,1}=NaN;
    end
end

% transformace dat do podoby pozadovane BN algoritmy uceni
samples = cell(N, nsamples);
for i = 1:N
    samples(i,:) = data_raw{1,i}';
end
